import { Bytes, Endian } from './types.js';
import * as fmt from './format/index.js';
export declare class Buff extends Uint8Array {
    static num: typeof numToBuff;
    static big: typeof bigToBuff;
    static bin: typeof binToBuff;
    static raw: typeof rawToBuff;
    static str: typeof strToBuff;
    static hex: typeof hexToBuff;
    static bytes: typeof buffer;
    static json: typeof jsonToBuff;
    static base64: typeof base64ToBuff;
    static b64url: typeof b64urlToBuff;
    static bech32: typeof bech32ToBuff;
    static b58chk: typeof b58chkToBuff;
    static encode: typeof fmt.strToBytes;
    static decode: typeof fmt.bytesToStr;
    static random(size?: number): Buff;
    constructor(data: Bytes | Bytes[] | ArrayBuffer, size?: number, endian?: Endian);
    get arr(): number[];
    get num(): number;
    get big(): bigint;
    get str(): string;
    get hex(): string;
    get raw(): Uint8Array;
    get bin(): string;
    get b58chk(): string;
    get base64(): string;
    get b64url(): string;
    get digest(): Buff;
    get id(): string;
    get stream(): Stream;
    toNum(endian?: Endian): number;
    toBin(): string;
    toBig(endian?: Endian): bigint;
    toHash(): Buff;
    toJson<T = any>(): T;
    toBech32(hrp: string, version?: number): string;
    toStr(): string;
    toHex(): string;
    toBytes(): Uint8Array;
    tob58chk(): string;
    toBase64(): string;
    toB64url(): string;
    prepend(data: Bytes): Buff;
    append(data: Bytes): Buff;
    slice(start?: number, end?: number): Buff;
    subarray(begin?: number, end?: number): Buff;
    reverse(): Buff;
    write(bytes: Bytes, offset?: number): void;
    prefixSize(endian?: Endian): Buff;
    static from(data: Uint8Array | number[]): Buff;
    static of(...args: number[]): Buff;
    static join(arr: Bytes[]): Buff;
    static varInt(num: number, endian?: Endian): Buff;
}
declare function numToBuff(number: number, size?: number, endian?: Endian): Buff;
declare function binToBuff(data: string, size?: number, endian?: Endian): Buff;
declare function bigToBuff(bigint: bigint, size?: number, endian?: Endian): Buff;
declare function rawToBuff(data: Uint8Array, size?: number, endian?: Endian): Buff;
declare function strToBuff(data: string, size?: number, endian?: Endian): Buff;
declare function hexToBuff(data: string, size?: number, endian?: Endian): Buff;
declare function jsonToBuff<T>(data: T): Buff;
declare function base64ToBuff(data: string): Buff;
declare function b64urlToBuff(data: string): Buff;
declare function bech32ToBuff(data: string): Buff;
declare function b58chkToBuff(data: string): Buff;
export declare class Stream {
    size: number;
    data: Uint8Array;
    constructor(data: Bytes);
    peek(size: number): Buff;
    read(size: number): Buff;
    readSize(endian?: Endian): number;
}
export declare function buffer(bytes: Bytes | Bytes[] | ArrayBuffer, size?: number, end?: Endian): Buff;
export {};
//# sourceMappingURL=buff.d.ts.map